@@ -34,11 +34,32 @@ from rime_sdk.protos.model_testing.model_testing_pb2 import (
     StartFirewallFromReferenceRequest,
     StartStressTestRequest,
 )
-from rime_sdk.protos.project.project_pb2 import CreateProjectRequest, GetProjectRequest
+from rime_sdk.protos.project.project_pb2 import (
+    CreateProjectRequest,
+    GetProjectRequest,
+    ListProjectsRequest,
+)
 from rime_sdk.protos.results_upload.results_upload_pb2 import DataType
 from rime_sdk.stress_test_job import RIMEStressTestJob
 
 
+def get_job_status_enum(job_status: str) -> "JobStatus.V":
+    """Get job status enum value from string."""
+    if job_status == "pending":
+        return JobStatus.JOB_STATUS_PENDING
+    elif job_status == "running":
+        return JobStatus.JOB_STATUS_RUNNING
+    elif job_status == "failed":
+        return JobStatus.JOB_STATUS_FAILED
+    elif job_status == "succeeded":
+        return JobStatus.JOB_STATUS_SUCCEEDED
+    else:
+        raise ValueError(
+            f"Got unknown job status ({job_status}), "
+            f"should be one of: `pending`, `running`, `failing`, `succeeded`"
+        )
+
+
 def get_data_type_enum(data_type: str) -> "DataType.V":
     """Get data type enum value from string."""
     if data_type == "tabular":
@@ -386,6 +407,58 @@ class RIMEClient:
             # TODO(blaine): differentiate on different error types.
             raise ValueError(e)
 
+    def list_projects(
+        self, page_token: str = "", page_size: int = 100,
+    ) -> Tuple[List[RIMEProject], str]:
+        """List projects in a paginated form.
+
+        Args:
+            page_token: str = ""
+                This identifies to the page of results to retrieve, and used for
+                paginating the API results. To get access to the next page of results,
+                use the second value in the tuple returned by the previous call.
+                Leave empty to retrieve the first page of results. used for paginating
+                the API results.
+            page_size: int = 200
+                This is the limit on the size of the page of results.
+                The default value is to return at most 200 projects.
+
+        Returns:
+            A ``Tuple[List[RIMEProject], str]`` of the list of projects and
+            the next page token.
+
+        Raises:
+            ValueError
+                If the request to the ProjectManager service fails.
+
+        Example:
+
+        .. code-block:: python
+
+            # Query for 100 projects.
+            projects, next_page_token, number = rime_client.list_projects()
+
+        """
+        req = ListProjectsRequest(page_token=page_token, page_size=page_size)
+
+        try:
+            with self._backend.get_project_manager_stub() as project_manager:
+                res = project_manager.ListProjects(request=req)
+                return (
+                    [
+                        RIMEProject(
+                            project_id=annotated_project.project.id,
+                            name=annotated_project.project.name,
+                            description=annotated_project.project.description,
+                        )
+                        for annotated_project in res.projects
+                    ],
+                    res.next_page_token,
+                )
+        except grpc.RpcError as e:
+            # TODO(blaine): differentiate on different error types.
+            raise ValueError(e)
+
     def start_stress_test(
         self,
         test_run_config: dict,
@@ -517,7 +590,7 @@ class RIMEClient:
             status_filters: Optional[List[str]] = None
                 Filter for selecting jobs by a union of statuses.
                 The following list enumerates all acceptable values.
-                ['UNKNOWN_JOB_STATUS', 'PENDING', 'RUNNING', 'FAILING', 'SUCCEEDED']
+                ['pending', 'running', 'failing', 'succeeded']
                 If omitted, jobs will not be filtered by status.
             project_id: Optional[str] = None
                 Filter for selecting jobs by project ID.
@@ -538,17 +611,15 @@ class RIMEClient:
 
             # Get all running and succeeded jobs for project 'foo'
             jobs = rime_client.list_stress_test_jobs(
-                status_filters=['RUNNING', 'SUCCEEDED'], project_id='foo')
+                status_filters=['JOB_STATUS_PENDING', 'JOB_STATUS_SUCCEEDED'],
+                project_id='foo',
+            )
         """
         req = ListTestJobsRequest()
         if status_filters:
-            # This throws a ValueError if status is not a valid JobStatus enum value.
-            # TODO(QuantumWombat): should we catch the error and show something more
-            #                      interpretable?
-            # It looks like -> ValueError: Enum JobStatus has no value defined for name
-            # 'does_not_exist'.
+            # This throws a ValueError if status is invalid.
             req.selected_statuses.extend(
-                [JobStatus.Value(status) for status in status_filters]
+                [get_job_status_enum(status) for status in status_filters]
             )
         if project_id and not self._project_exists(project_id):
             raise ValueError("Project id {} does not exist".format(project_id))
