@@ -3,14 +3,12 @@
 from typing import Any, Callable, Generic, Optional, TypeVar
 
 import grpc
-from deprecated import deprecated
 
 from rime_sdk.protos.file_upload.file_upload_pb2_grpc import FileUploadStub
 from rime_sdk.protos.firewall.firewall_pb2_grpc import FirewallServiceStub
 from rime_sdk.protos.image_registry.image_registry_pb2_grpc import ImageRegistryStub
 from rime_sdk.protos.model_testing.model_testing_pb2_grpc import ModelTestingStub
 from rime_sdk.protos.project.project_pb2_grpc import ProjectManagerStub
-from rime_sdk.protos.results_upload.results_upload_pb2_grpc import ResultsStoreStub
 from rime_sdk.protos.test_run_results.test_run_results_pb2_grpc import ResultsReaderStub
 from rime_sdk.protos.test_run_tracker.test_run_tracker_pb2_grpc import (
     TestRunTrackerStub,
@@ -202,19 +200,6 @@ class RIMEBackend:
             disable_tls=self._disable_tls,
         )
 
-    @deprecated(
-        version="0.15.0", reason="Use `get_test_run_results_stub()` instead",
-    )
-    def get_result_store_stub(self) -> RIMEConnection[ResultsStoreStub]:
-        """Return a result store client."""
-        return RIMEConnection[ResultsStoreStub](
-            ResultsStoreStub,
-            self._backend_addr,
-            self._api_key,
-            channel_timeout=self._channel_timeout,
-            disable_tls=self._disable_tls,
-        )
-
     def get_test_run_tracker_stub(self) -> RIMEConnection[TestRunTrackerStub]:
         """Return a test run tracker client."""
         return RIMEConnection[TestRunTrackerStub](
