@@ -54,10 +54,14 @@ class FileUploadModule:
             raise FileNotFoundError(f"path '{file_path}' does not exist")
         if not file_path.is_file():
             raise IOError(f"path '{file_path}' is not a file")
+
+        file_size = file_path.stat().st_size
+
         file_name = file_path.name
         req = GetDatasetFileUploadURLRequest(file_name=file_name)
         try:
             resp = self._file_upload_client.GetDatasetFileUploadURL(request=req)
+            self._impose_size_constraint(file_size, resp.upload_limit)
         except grpc.RpcError as e:
             # TODO(blaine): differentiate on different error types.
             raise ValueError(e)
@@ -110,8 +114,10 @@ class FileUploadModule:
             )
         )
         rel_paths: List[Text] = []
+        total_size: int = 0
         for file_path in sub_paths:
             if file_path.is_file():
+                total_size += file_path.stat().st_size
                 rel_paths.append(str(file_path.relative_to(dir_path)))
         if len(rel_paths) == 0:
             raise IOError(f"directory '{dir_path}' is empty")
@@ -120,6 +126,7 @@ class FileUploadModule:
         )
         try:
             resp = self._file_upload_client.GetModelDirectoryUploadURLs(request=req)
+            self._impose_size_constraint(total_size, resp.upload_limit)
         except grpc.RpcError as e:
             # TODO(blaine): differentiate on different error types.
             raise ValueError(e)
@@ -155,6 +162,14 @@ class FileUploadModule:
         session.mount("https://", adapter)
         return session
 
+    def _impose_size_constraint(self, size: int, upload_limit: int) -> None:
+        if (upload_limit != 0) and (size > upload_limit):
+            raise ValueError(
+                "Input is too large to be uploaded. Maximum size permitted "
+                + f"is {upload_limit / (10 ** 6)}MB. "
+                + f"Input size given is {size / (10 ** 6)}MB"
+            )
+
     def _upload_string(self, file_contents: str, upload_url: str) -> None:
         """Upload `file_contents` to the location at `upload_url` via a PUT request."""
         with self._get_requests_session() as session:
